@@ -1,8 +1,14 @@
 #!/usr/bin/env python
-# $Id: ImportManager.py,v 1.1 2002/04/27 01:36:33 tavis_rudd Exp $
+# $Id: ImportManager.py,v 1.6 2007/04/03 01:56:24 tavis_rudd Exp $
 
 """Provides an emulator/replacement for Python's standard import system.
 
+@@TR: Be warned that Import Hooks are in the deepest, darkest corner of Python's
+jungle.  If you need to start hacking with this, be prepared to get lost for a
+while. Also note, this module predates the newstyle import hooks in Python 2.3
+http://www.python.org/peps/pep-0302.html.  
+
+
 This is a hacked/documented version of Gordon McMillan's iu.py. I have:
 
   - made it a little less terse
@@ -17,13 +23,13 @@ Meta-Data
 ================================================================================
 Author: Tavis Rudd <tavis@damnsimple.com>  based on Gordon McMillan's iu.py
 License: This software is released for unlimited distribution under the
-         terms of the Python license.
-Version: $Revision: 1.1 $
+         terms of the MIT license.  See the LICENSE file.
+Version: $Revision: 1.6 $
 Start Date: 2001/03/30
-Last Revision Date: $Date: 2002/04/27 01:36:33 $
+Last Revision Date: $Date: 2007/04/03 01:56:24 $
 """ 
 __author__ = "Tavis Rudd <tavis@damnsimple.com>"
-__revision__ = "$Revision: 1.1 $"[11:-2]
+__revision__ = "$Revision: 1.6 $"[11:-2]
 
 ##################################################
 ## DEPENDENCIES
@@ -74,7 +80,6 @@ def _os_bootstrap():
         def join(a, b):
             if a == '':
                 return b
-            path = s
             if ':' not in a:
                 a = ':' + a
             if a[-1:] != ':':
